'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

function styleInject(css, ref) {
  if (ref === void 0) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') {
    return;
  }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = ".code__data {\n  margin: 0;\n}\n.code__line--comment {\n  color: green;\n}\n.code--keyword {\n  font-weight: bold;\n  color: purple;\n}\n\n.dark .code__line--comment {\n  color: rgb(89, 235, 89);\n}\n.dark .code--keyword {\n  font-weight: bold;\n  color: rgb(197, 50, 197);\n}";
styleInject(css_248z);

var forEachKeyword = function (callback) {
    var keywords = ["const", "let", "if", "else"];
    for (var keywordIndex = 0; keywordIndex < keywords.length; keywordIndex++) {
        var keyword = keywords[keywordIndex];
        callback(keyword, keywordIndex);
    }
};
var searchKeyword = function (line, keyword, keywordIndex, startPos) {
    if (startPos === void 0) { startPos = 0; }
    var keywordPos = line.indexOf(keyword, startPos);
    if (keywordPos > -1) {
        return { result: true, pos: keywordPos };
    }
    return { result: false, pos: -1 };
};
var highlightKeyword = function (line, keyword, keywordPos) {
    var sub0 = line.substring(0, keywordPos);
    var sub1 = line.substring(keywordPos, keywordPos + keyword.length);
    var sub2 = line.substring(keywordPos + keyword.length, line.length);
    var wrapped = React__default["default"].createElement("span", { className: "code--keyword" }, sub1);
    var result = React__default["default"].createElement("span", null,
        sub0,
        wrapped,
        sub2);
    return result;
};
var isCommentLine = function (line) {
    var startsWithDoubleSlash = function (line) { return line[0] === "/" && line[1] === "/"; };
    return (startsWithDoubleSlash(line)) ? true : false;
};
var styleLineAsComment = function (line) {
    return React__default["default"].createElement("span", { className: "code__line--comment" }, line);
};
var forEachLine = function (code_as_string, callback) {
    var code_as_array = code_as_string.split("\n");
    var output_array = [];
    for (var lineIndex = 0; lineIndex < code_as_array.length; lineIndex++) {
        var line = code_as_array[lineIndex];
        line = callback(line, lineIndex);
        for (var i = 0; i < line.length; i++) {
            output_array.push(line[i]);
        }
    }
    return output_array;
};
var returnCode = function (code_as_string) {
    return React__default["default"].createElement("pre", { className: 'code__data' }, forEachLine(code_as_string, function (line, lineIndex) {
        if (isCommentLine(line))
            return [styleLineAsComment(line)];
        else {
            var result_1 = [];
            var orig_line_1 = line;
            var no_hit_1 = true;
            forEachKeyword(function (keyword, keywordIndex) {
                var keywordsearch = searchKeyword(orig_line_1, keyword);
                if (keywordsearch.result === true)
                    while (keywordsearch.result === true) {
                        no_hit_1 = false;
                        result_1.push(highlightKeyword(orig_line_1, keyword, keywordsearch.pos));
                        keywordsearch = searchKeyword(orig_line_1, keyword, keywordIndex, keyword.length + keywordsearch.pos);
                    }
            });
            if (no_hit_1)
                result_1.push(line);
            return result_1;
        }
    }).map(function (line, lineIndex) {
        return React__default["default"].createElement("span", { key: lineIndex },
            line,
            React__default["default"].createElement("br", null));
    }));
};

exports.createStyledCodeblock = returnCode;
//# sourceMappingURL=index.js.map
